@@ -21,16 +21,18 @@
 
 # Created by rszabo50 at 2022-02-01
 
-import subprocess
-import traceback
-import os
-import time
 import logging
+import os
+import subprocess
+import time
+import traceback
+
 from urwid import Columns, AttrWrap, Text, RIGHT, raw_display, Pile, ListBox, SimpleListWalker
-from ucm.Widgets import ListView, ListItem
+
+from ucm.Dialogs import DialogDisplay
 from ucm.Registry import Registry
 from ucm.UserConfig import UserConfig
-from ucm.Dialogs import DialogDisplay
+from ucm.Widgets import ListView
 from ucm.constants import MAIN_PALETTE
 
 
@@ -89,7 +91,7 @@ class DockerListView(ListView):
     @staticmethod
     def popup_info_dialog(data):
         cols, rows = raw_display.Screen().get_cols_rows()
-        d = DialogDisplay(f"Container Inpsection: {data['name']}", cols - 20, rows - 6,
+        d = DialogDisplay(f"Container Inspection: {data['name']}", cols - 20, rows - 6,
                           body=Pile([
                               ListBox(
                                   SimpleListWalker(docker_inspect(data))
@@ -114,6 +116,7 @@ class DockerListView(ListView):
             docker_connect(data, shell='bash')
         if key == 'i':
             DockerListView.popup_info_dialog(data)
+        super().keypress_callback(size, key, data)
 
     def get_filter_widgets(self):
         return Columns([
